@@ -2,14 +2,18 @@
 
 use Mail::Cclient;
 
-my $smtp = Mail::Cclient::SMTP->new(["smtp1.perl.org","smtp2.perl.org"]);
+my $smtp = Mail::Cclient::SMTP->new(
+	hostlist => ["smtp1.perl.org", "smtp2.perl.org"],
+	service  => "smtp",
+	port     => 25
+);
 
 $smtp->mail(
 	transaction => "mail",
-	defaulthost => "perl.org",
+	defaulthost => "rosa.esb.ucp.pt",
 	envelope => {
 		from        => "hdias\@perl.org",
-		to          => "mallcom\@perl.org",
+		to          => "hdias\@aesbuc.pt",
 		subject     => "this is a test",
 	},
 	body => {
